@@ -4,11 +4,13 @@ from typing import Any, Callable, ClassVar, Dict, Generic, Optional, Tuple, Type
 
 import pydantic as pd
 import pydantic_core as pdc
+import typing_extensions as te
 from pydantic import BaseModel, RootModel
 from pydantic._internal._model_construction import ModelMetaclass  # noqa
+from pydantic.root_model import _RootModelMetaclass as RootModelMetaclass  # noqa
 
 from . import config, errors, utils
-from .element import SearchMode
+from .element import SearchMode, XmlElementReader, XmlElementWriter
 from .element.native import ElementT, XmlElement, etree
 from .serializers.factories.model import BaseModelSerializer
 from .serializers.serializer import Serializer, XmlEntityInfoP
@@ -17,10 +19,13 @@ from .utils import NsMap
 
 __all__ = (
     'attr',
+    'create_model',
     'element',
     'wrapped',
     'computed_attr',
     'computed_element',
+    'xml_field_serializer',
+    'xml_field_validator',
     'BaseXmlModel',
     'RootXmlModel',
 )
@@ -248,6 +253,109 @@ def wrapped(
     )
 
 
+Model = TypeVar('Model', bound='BaseXmlModel')
+
+
+def create_model(
+        __model_name: str,
+        *,
+        __tag__: Optional[str] = None,
+        __ns__: Optional[str] = None,
+        __nsmap__: Optional[NsMap] = None,
+        __ns_attrs__: Optional[bool] = None,
+        __skip_empty__: Optional[bool] = None,
+        __search_mode__: Optional[SearchMode] = None,
+        __base__: Union[Type[Model], Tuple[Type[Model], ...], None] = None,
+        __module__: Optional[str] = None,
+        **kwargs: Any,
+) -> Type[Model]:
+    """
+    Dynamically creates a new pydantic-xml model.
+
+    :param __model_name: model name
+    :param __tag__: element tag
+    :param __ns__: element namespace
+    :param __nsmap__: element namespace map
+    :param __ns_attrs__: use namespaced attributes
+    :param __skip_empty__: skip empty elements (elements without sub-elements, attributes and text)
+    :param __search_mode__: element search mode
+    :param __base__: model base class
+    :param __module__: module name that the model belongs to
+    :param kwargs: pydantic model creation arguments.
+                   See https://docs.pydantic.dev/latest/api/base_model/#pydantic.create_model.
+
+    :return: created model
+    """
+
+    cls_kwargs = kwargs.setdefault('__cls_kwargs__', {})
+    cls_kwargs['metaclass'] = XmlModelMeta
+
+    cls_kwargs['tag'] = __tag__
+    cls_kwargs['ns'] = __ns__
+    cls_kwargs['nsmap'] = __nsmap__
+    cls_kwargs['ns_attrs'] = __ns_attrs__
+    cls_kwargs['skip_empty'] = __skip_empty__
+    cls_kwargs['search_mode'] = __search_mode__
+
+    model_base: Union[Type[BaseModel], Tuple[Type[BaseModel], ...]] = __base__ or BaseXmlModel
+
+    if model_config := kwargs.pop('__config__', None):
+        # since pydantic create_model function forbids __base__ and __config__ arguments together,
+        # we create base pydantic class with __config__ and inherit from it
+        BaseWithConfig = pd.create_model(
+            f'{__model_name}Base',
+            __module__=__module__,  # type: ignore[arg-type]
+            __config__=model_config,
+        )
+        if not isinstance(model_base, tuple):
+            model_base = (model_base, BaseWithConfig)
+        else:
+            model_base = (*model_base, BaseWithConfig)
+
+    model = pd.create_model(__model_name, __base__=model_base, **kwargs)
+
+    return typing.cast(Type[Model], model)
+
+
+ValidatorFunc = Callable[[Type['BaseXmlModel'], XmlElementReader, str], Any]
+ValidatorFuncT = TypeVar('ValidatorFuncT', bound=ValidatorFunc)
+
+
+def xml_field_validator(field: str, /, *fields: str) -> Callable[[ValidatorFuncT], ValidatorFuncT]:
+    """
+    Marks the method as a field xml validator.
+
+    :param field: field to be validated
+    :param fields: fields to be validated
+    """
+
+    def wrapper(func: ValidatorFuncT) -> ValidatorFuncT:
+        setattr(func, '__xml_field_validator__', (field, *fields))
+        return func
+
+    return wrapper
+
+
+SerializerFunc = Callable[['BaseXmlModel', XmlElementWriter, Any, str], Any]
+SerializerFuncT = TypeVar('SerializerFuncT', bound=SerializerFunc)
+
+
+def xml_field_serializer(field: str, /, *fields: str) -> Callable[[SerializerFuncT], SerializerFuncT]:
+    """
+    Marks the method as a field xml serializer.
+
+    :param field: field to be serialized
+    :param fields: fields to be serialized
+    """
+
+    def wrapper(func: SerializerFuncT) -> SerializerFuncT:
+        setattr(func, '__xml_field_serializer__', (field, *fields))
+        return func
+
+    return wrapper
+
+
+@te.dataclass_transform(kw_only_default=True, field_specifiers=(attr, element, wrapped, pd.Field))
 class XmlModelMeta(ModelMetaclass):
     """
     Xml model metaclass.
@@ -285,6 +393,9 @@ class BaseXmlModel(BaseModel, __xml_abstract__=True, metaclass=XmlModelMeta):
     __xml_search_mode__: ClassVar[SearchMode]
     __xml_serializer__: ClassVar[Optional[BaseModelSerializer]] = None
 
+    __xml_field_validators__: ClassVar[Dict[str, ValidatorFunc]] = {}
+    __xml_field_serializers__: ClassVar[Dict[str, SerializerFunc]] = {}
+
     def __init_subclass__(
             cls,
             tag: Optional[str] = None,
@@ -302,6 +413,7 @@ class BaseXmlModel(BaseModel, __xml_abstract__=True, metaclass=XmlModelMeta):
         :param ns: element namespace
         :param nsmap: element namespace map
         :param ns_attrs: use namespaced attributes
+        :param skip_empty: skip empty elements (elements without sub-elements, attributes and text)
         :param search_mode: element search mode
         """
 
@@ -315,6 +427,22 @@ class BaseXmlModel(BaseModel, __xml_abstract__=True, metaclass=XmlModelMeta):
         cls.__xml_search_mode__ = search_mode if search_mode is not None \
             else getattr(cls, '__xml_search_mode__', SearchMode.STRICT)
 
+        cls.__xml_field_serializers__ = {}
+        cls.__xml_field_validators__ = {}
+
+        # find custom validators/serializers in all defined attributes
+        # though we want to skip any Base(Xml)Model attributes, as these can never be field
+        # serializers/validators, and getting certain pydantic fields, like __pydantic_post_init__
+        # may cause recursion errors for recursive / self-referential models
+        for attr_name in set(dir(cls)) - set(dir(BaseXmlModel)):
+            if func := getattr(cls, attr_name, None):
+                if fields := getattr(func, '__xml_field_serializer__', None):
+                    for field in fields:
+                        cls.__xml_field_serializers__[field] = func
+                if fields := getattr(func, '__xml_field_validator__', None):
+                    for field in fields:
+                        cls.__xml_field_validators__[field] = func
+
     @classmethod
     def __build_serializer__(cls) -> None:
         if cls is BaseXmlModel:
@@ -400,11 +528,15 @@ class BaseXmlModel(BaseModel, __xml_abstract__=True, metaclass=XmlModelMeta):
 
         return cls.from_xml_tree(etree.fromstring(source), context=context)
 
-    def to_xml_tree(self, *, skip_empty: bool = False) -> etree.Element:
+    def to_xml_tree(
+            self, *, skip_empty: bool = False, exclude_none: bool = False, exclude_unset: bool = False,
+    ) -> etree.Element:
         """
         Serializes the object to an xml tree.
 
         :param skip_empty: skip empty elements (elements without sub-elements, attributes and text, Nones)
+        :param exclude_none: exclude `None` values
+        :param exclude_unset: exclude values that haven't been explicitly set
         :return: object xml representation
         """
 
@@ -416,21 +548,36 @@ class BaseXmlModel(BaseModel, __xml_abstract__=True, metaclass=XmlModelMeta):
                 self,
                 by_alias=False,
                 fallback=lambda obj: obj if not isinstance(obj, ElementT) else None,  # for raw fields support
-            ), skip_empty=skip_empty,
+            ),
+            skip_empty=skip_empty,
+            exclude_none=exclude_none,
+            exclude_unset=exclude_unset,
         )
 
         return root.to_native()
 
-    def to_xml(self, *, skip_empty: bool = False, **kwargs: Any) -> Union[str, bytes]:
+    def to_xml(
+            self, *, skip_empty: bool = False, exclude_none: bool = False, exclude_unset: bool = False, **kwargs: Any,
+    ) -> Union[str, bytes]:
         """
         Serializes the object to an xml string.
 
         :param skip_empty: skip empty elements (elements without sub-elements, attributes and text, Nones)
+        :param exclude_none: exclude `None` values
+        :param exclude_unset: exclude values that haven't been explicitly set
         :param kwargs: additional xml serialization arguments
         :return: object xml representation
         """
 
-        return etree.tostring(self.to_xml_tree(skip_empty=skip_empty), **kwargs)
+        return etree.tostring(
+            self.to_xml_tree(skip_empty=skip_empty, exclude_none=exclude_none, exclude_unset=exclude_unset),
+            **kwargs,
+        )
+
+
+@te.dataclass_transform(kw_only_default=True, field_specifiers=(attr, element, wrapped, pd.Field))
+class RootXmlModelMeta(XmlModelMeta, RootModelMetaclass):
+    pass
 
 
 RootModelRootType = TypeVar('RootModelRootType')
@@ -440,6 +587,7 @@ class RootXmlModel(
     RootModel[RootModelRootType],
     BaseXmlModel,
     Generic[RootModelRootType],
+    metaclass=RootXmlModelMeta,
     __xml_abstract__=True,
 ):
     """
