@@ -11,7 +11,7 @@ from pydantic_xml.typedefs import EntityLocation, Location
 
 class ElementSerializer(Serializer):
     @classmethod
-    def from_core_schema(cls, schema: pcs.TuplePositionalSchema, ctx: Serializer.Context) -> 'ElementSerializer':
+    def from_core_schema(cls, schema: pcs.TupleSchema, ctx: Serializer.Context) -> 'ElementSerializer':
         model_name = ctx.model_name
         computed = ctx.field_computed
         inner_serializers: List[Serializer] = []
@@ -26,7 +26,14 @@ class ElementSerializer(Serializer):
         self._inner_serializers = inner_serializers
 
     def serialize(
-            self, element: XmlElementWriter, value: List[Any], encoded: List[Any], *, skip_empty: bool = False,
+            self,
+            element: XmlElementWriter,
+            value: List[Any],
+            encoded: List[Any],
+            *,
+            skip_empty: bool = False,
+            exclude_none: bool = False,
+            exclude_unset: bool = False,
     ) -> Optional[XmlElementWriter]:
         if value is None:
             return element
@@ -38,7 +45,9 @@ class ElementSerializer(Serializer):
             raise errors.SerializationError("value length is incorrect")
 
         for serializer, val, enc in zip(self._inner_serializers, value, encoded):
-            serializer.serialize(element, val, enc, skip_empty=skip_empty)
+            serializer.serialize(
+                element, val, enc, skip_empty=skip_empty, exclude_none=exclude_none, exclude_unset=exclude_unset,
+            )
 
         return element
 
@@ -65,7 +74,7 @@ class ElementSerializer(Serializer):
                 item_errors[idx] = err
 
         if item_errors:
-            raise utils.build_validation_error(title=self._model_name, errors_map=item_errors)
+            raise utils.into_validation_error(title=self._model_name, errors_map=item_errors)
 
         if all((value is None for value in result)):
             return None
@@ -73,7 +82,7 @@ class ElementSerializer(Serializer):
             return result
 
 
-def from_core_schema(schema: pcs.TuplePositionalSchema, ctx: Serializer.Context) -> Serializer:
+def from_core_schema(schema: pcs.TupleSchema, ctx: Serializer.Context) -> Serializer:
     for item_schema in schema['items_schema']:
         item_schema, ctx = Serializer.preprocess_schema(item_schema, ctx)
 
@@ -84,7 +93,9 @@ def from_core_schema(schema: pcs.TuplePositionalSchema, ctx: Serializer.Context)
                 SchemaTypeFamily.MAPPING,
                 SchemaTypeFamily.TYPED_MAPPING,
                 SchemaTypeFamily.UNION,
+                SchemaTypeFamily.TAGGED_UNION,
                 SchemaTypeFamily.IS_INSTANCE,
+                SchemaTypeFamily.CALL,
         ):
             raise errors.ModelFieldError(
                 ctx.model_name, ctx.field_name, "collection item must be of primitive, model, mapping or union type",
