@@ -57,7 +57,7 @@ class ModelSerializer(BaseModelSerializer):
         model_cls = schema['cls']
         fields_schema = schema['schema']
 
-        if fields_schema['type'] == 'function-before':
+        while fields_schema['type'] == 'function-before':
             fields_schema = fields_schema['schema']
 
         assert issubclass(model_cls, pxml.BaseXmlModel), "model class must be a BaseXmlModel subclass"
@@ -158,6 +158,8 @@ class ModelSerializer(BaseModelSerializer):
             encoded: Dict[str, Any],
             *,
             skip_empty: bool = False,
+            exclude_none: bool = False,
+            exclude_unset: bool = False,
     ) -> Optional[XmlElementWriter]:
         if value is None:
             return None
@@ -166,9 +168,19 @@ class ModelSerializer(BaseModelSerializer):
             skip_empty = self._model.__xml_skip_empty__
 
         for field_name, field_serializer in self._field_serializers.items():
-            if field_name not in self._fields_serialization_exclude:
+            if field_name in self._fields_serialization_exclude:
+                continue
+            if exclude_unset and field_name not in value.__pydantic_fields_set__:
+                continue
+
+            if custom_field_serializer := self._model.__xml_field_serializers__.get(field_name):
+                custom_field_serializer(value, element, getattr(value, field_name), field_name)
+            else:
                 field_serializer.serialize(
-                    element, getattr(value, field_name), encoded[field_name], skip_empty=skip_empty,
+                    element, getattr(value, field_name), encoded[field_name],
+                    skip_empty=skip_empty,
+                    exclude_none=exclude_none,
+                    exclude_unset=exclude_unset,
                 )
 
         return element
@@ -190,7 +202,11 @@ class ModelSerializer(BaseModelSerializer):
             try:
                 loc = (field_name,)
                 sourcemap[loc] = element.get_sourceline()
-                field_value = field_serializer.deserialize(element, context=context, sourcemap=sourcemap, loc=loc)
+                if custom_field_validator := self._model.__xml_field_validators__.get(field_name):
+                    field_value = custom_field_validator(self._model, element, field_name)
+                else:
+                    field_value = field_serializer.deserialize(element, context=context, sourcemap=sourcemap, loc=loc)
+
                 if field_value is not None:
                     field_name = self._fields_validation_aliases.get(field_name, field_name)
                     result[field_name] = field_value
@@ -198,7 +214,7 @@ class ModelSerializer(BaseModelSerializer):
                 field_errors[field_name] = err
 
         if field_errors:
-            raise utils.build_validation_error(title=self._model.__name__, errors_map=field_errors)
+            raise utils.into_validation_error(title=self._model.__name__, errors_map=field_errors)
 
         if self._model.model_config.get('extra', 'ignore') == 'forbid':
             self._check_extra(self._model.__name__, element)
@@ -269,14 +285,24 @@ class RootModelSerializer(BaseModelSerializer):
             encoded: Dict[str, Any],
             *,
             skip_empty: bool = False,
+            exclude_none: bool = False,
+            exclude_unset: bool = False,
     ) -> Optional[XmlElementWriter]:
         if value is None:
             return None
 
+        if exclude_unset and 'root' not in value.__pydantic_fields_set__:
+            return None
+
         if self._model.__xml_skip_empty__ is not None:
             skip_empty = self._model.__xml_skip_empty__
 
-        self._root_serializer.serialize(element, getattr(value, 'root'), encoded, skip_empty=skip_empty)
+        self._root_serializer.serialize(
+            element, getattr(value, 'root'), encoded,
+            skip_empty=skip_empty,
+            exclude_none=exclude_none,
+            exclude_unset=exclude_unset,
+        )
 
         return element
 
@@ -296,7 +322,7 @@ class RootModelSerializer(BaseModelSerializer):
             if result is None:
                 result = pdc.PydanticUndefined
         except pd.ValidationError as err:
-            raise utils.build_validation_error(title=self._model.__name__, errors_map={None: err})
+            raise utils.into_validation_error(title=self._model.__name__, errors_map={None: err})
 
         if self._model.model_config.get('extra', 'ignore') == 'forbid':
             self._check_extra(self._model.__name__, element)
@@ -362,9 +388,14 @@ class ModelProxySerializer(BaseModelSerializer):
             encoded: Dict[str, Any],
             *,
             skip_empty: bool = False,
+            exclude_none: bool = False,
+            exclude_unset: bool = False,
     ) -> Optional[XmlElementWriter]:
         assert self._model.__xml_serializer__ is not None, f"model {self._model.__name__} is partially initialized"
 
+        if exclude_none and value is None:
+            return None
+
         if self._nillable and value is None:
             sub_element = element.make_element(self._element_name, nsmap=self._nsmap)
             make_element_nill(sub_element)
@@ -375,7 +406,9 @@ class ModelProxySerializer(BaseModelSerializer):
             return None
 
         sub_element = element.make_element(self._element_name, nsmap=self._nsmap)
-        self._model.__xml_serializer__.serialize(sub_element, value, encoded, skip_empty=skip_empty)
+        self._model.__xml_serializer__.serialize(
+            sub_element, value, encoded, skip_empty=skip_empty, exclude_none=exclude_none, exclude_unset=exclude_unset,
+        )
         if skip_empty and sub_element.is_empty():
             return None
         else:
