@@ -30,7 +30,14 @@ class ElementSerializer(Serializer):
         self._element_name = QName.from_alias(tag=name, ns=ns, nsmap=nsmap).uri
 
     def serialize(
-            self, element: XmlElementWriter, value: Any, encoded: Any, *, skip_empty: bool = False,
+            self,
+            element: XmlElementWriter,
+            value: Any,
+            encoded: Any,
+            *,
+            skip_empty: bool = False,
+            exclude_none: bool = False,
+            exclude_unset: bool = False,
     ) -> Optional[XmlElementWriter]:
         if value is None:
             return element
@@ -56,7 +63,7 @@ class ElementSerializer(Serializer):
         if element is None:
             return None
 
-        if (sub_element := element.pop_element(self._element_name, self._search_mode)) is not None:
+        if (sub_element := element.pop_element(self._element_name, self._search_mode, remove=True)) is not None:
             sourcemap[loc] = sub_element.get_sourceline()
             return sub_element.to_native()
         else:
